Index: src/gpu/GrReducedClip.h |
diff --git a/src/gpu/GrReducedClip.h b/src/gpu/GrReducedClip.h |
index 21899c73aae73d1f6cfc7abb51a970a92b436354..a0ce08a04332bc3aa85441fd67cbfb234d0272ab 100644 |
--- a/src/gpu/GrReducedClip.h |
+++ b/src/gpu/GrReducedClip.h |
@@ -27,10 +27,10 @@ public: |
* the list of elements is returned in resultGenID. The initial state of the |
* query rectangle before the first clip element is applied is returned via |
* initialState. Optionally, the caller can request a tighter bounds on the |
* clip be returned via tighterBounds. If not NULL, tighterBounds will |
* always be contained by queryBounds after return. If tighterBounds is |
* specified then it is assumed that the caller will implicitly clip against |
* it. If the caller specifies non-NULL for requiresAA then it will indicate |
* whether anti-aliasing is required to process any of the elements in the |
* result. |
* |
@@ -42,8 +42,8 @@ public: |
ElementList* result, |
int32_t* resultGenID, |
InitialState* initialState, |
- SkIRect* tighterBounds = NULL, |
- bool* requiresAA = NULL); |
+ SkIRect* tighterBounds = nullptr, |
+ bool* requiresAA = nullptr); |
}; |
#endif |
@@ -27,10 +27,10 @@ public: |
* query rectangle before the first clip element is applied is returned via |
* initialState. Optionally, the caller can request a tighter bounds on the |
- * clip be returned via tighterBounds. If not NULL, tighterBounds will |
+ * clip be returned via tighterBounds. If not nullptr, tighterBounds will |
* always be contained by queryBounds after return. If tighterBounds is |
* specified then it is assumed that the caller will implicitly clip against |
@@ -27,10 +27,10 @@ public: |
* always be contained by queryBounds after return. If tighterBounds is |
* specified then it is assumed that the caller will implicitly clip against |
- * it. If the caller specifies non-NULL for requiresAA then it will indicate |
+ * it. If the caller specifies non-nullptr for requiresAA then it will indicate |
* whether anti-aliasing is required to process any of the elements in the |
* result. |